@@ -13,6 +13,7 @@
 
 from oslo_serialization import jsonutils
 
+from aodhclient import utils
 from aodhclient.v2 import base
 
 
@@ -20,13 +21,24 @@ class AlarmHistoryManager(base.Manager):
 
     url = "v2/alarms/%s/history"
 
-    def get(self, alarm_id):
+    def get(self, alarm_id, limit=None, marker=None, sorts=None):
         """Get history of an alarm
 
         :param alarm_id: ID of the alarm
         :type alarm_id: str
+        :param limit:    maximum number of resources to return
+        :type limit: int
+        :param marker: the last item of the previous page; we return the next
+                       results after this value.
+        :type marker: str
+        :param sorts: list of resource attributes to order by.
+        :type sorts: list of str
         """
-        return self._get(self.url % alarm_id).json()
+        pagination = utils.get_pagination_options(limit, marker, sorts)
+        url = self.url % alarm_id
+        if pagination:
+            url = "%s?%s" % (url, pagination)
+        return self._get(url).json()
 
     def search(self, query=None):
         """List of history matching corresponding query
